@@ -3,6 +3,7 @@ from typing import List, Type
 
 from pydoctest.parsers.parser import Parameter, Parser
 from pydoctest.utilities import get_type_from_module
+from pydoctest.exceptions import ParseException
 
 
 class GoogleParser(Parser):
@@ -35,12 +36,15 @@ class GoogleParser(Parser):
 
         parameters = []
         for arg_string in args_strings:
-            docname, tail = [x.strip() for x in arg_string.split('(')]
-            doctype, tail = tail.split(':')
-            doctype = doctype.replace(')', '')
-            doctype = doctype.replace(', optional', '')  # TODO: How do we deal with Optional[int] being (Optional[int], optional)?
-            located_type = get_type_from_module(doctype, module_type)
-            parameters.append(Parameter(docname, located_type.type))
+            try:
+                docname, tail = [x.strip() for x in arg_string.split('(')]
+                doctype, tail = tail.split(':')
+                doctype = doctype.replace(')', '')
+                doctype = doctype.replace(', optional', '')  # TODO: How do we deal with Optional[int] being (Optional[int], optional)?
+                located_type = get_type_from_module(doctype, module_type)
+                parameters.append(Parameter(docname, located_type.type))
+            except ValueError:
+                raise ParseException(arg_string)
         return parameters
 
     def get_return_type(self, doc: str, module_type: ModuleType) -> Type:
