@@ -13,7 +13,7 @@ class TextReporter(Reporter):
         """Returns the text output by walking the ValidationResult object.
 
         Args:
-            result (ValidationResult): The results from running Pydoctest
+            result (ValidationResult): The results from running Pydoctest.
 
         Returns:
             str: The output to be returned.
@@ -25,6 +25,14 @@ class TextReporter(Reporter):
         return output
 
     def get_module_output(self, result: ModuleValidationResult) -> str:
+        """Returns the text output from the result object from walking the module.
+
+        Args:
+            result (ModuleValidationResult): The result from running Pydoctest on the module.
+
+        Returns:
+            str: The output of the module.
+        """
         output = ""
         for f_r in result.function_results:
             output += self.get_function_output(f_r)
@@ -35,20 +43,36 @@ class TextReporter(Reporter):
         return output
 
     def get_function_output(self, result: FunctionValidationResult) -> str:
+        """Returns the text output from the result object from the function.
+
+        Args:
+            result (FunctionValidationResult): The result from running Pydoctest on the function.
+
+        Returns:
+            str: The output from the function.
+        """
         if result.result == ResultType.OK:
             if self.config.verbosity == Verbosity.SHOW_ALL:
-                return f"Function: {result.function.__module__}:{result.function.__name__} {SUCCESS}\n"
+                return f"Function: {result.function} {SUCCESS}\n"
             return ""
 
         if result.result == ResultType.FAILED:
-            return f"Function: {result.function.__module__}:{result.function.__name__} {FAILED} | {result.fail_reason}\n"
+            return f"Function: {result.function} {FAILED} | {result.fail_reason}\n"
 
         if result.result == ResultType.NO_DOC and self.config.fail_on_missing_docstring:
-            return f"Function: {result.function.__name__} is missing a docstring"
+            return f"Function: {result.function} is missing a docstring\n"
 
         return ""
 
     def get_class_output(self, result: ClassValidationResult) -> str:
+        """Returns the text output from the result object from the class.
+
+        Args:
+            result (ClassValidationResult): The result from running Pydoctest on the class.
+
+        Returns:
+            str: The output of the class and its functions.
+        """
         output = ""
         for fn in result.function_results:
             output += self.get_function_output(fn)
